==> fastocr-0.3.1.tar.gz: fastocr-0.3.1/fastocr/i18n/zh_cn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AppTray</name>
    <message>
        <source>Capture</source>
        <translation>捕获</translation>
    </message>
    <message>
        <source>Capture (Other Languages)</source>
        <translation>捕获（其他语言）</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <source>Default backend</source>
        <translation>默认后端</translation>
    </message>
    <message>
        <source>BaiduOCR</source>
        <translation>百度文字识别服务</translation>
    </message>
    <message>
        <source>YoudaoOCR</source>
        <translation>有道 OCR 识别服务</translation>
    </message>
    <message>
        <source>Face++OCR</source>
        <translation>Face++ OCR 识别服务</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>图标主题</translation>
    </message>
    <message>
        <source>Auto Select</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>亮色</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>暗色</translation>
    </message>
    <message>
        <source>Working mode</source>
        <translation>工作模式</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>复制到系统剪贴板</translation>
    </message>
    <message>
        <source>Show notification only</source>
        <translation>仅显示通知</translation>
    </message>
    <message>
        <source>APP_ID</source>
        <translation>APP_ID</translation>
    </message>
    <message>
        <source>API_KEY</source>
        <translation>API_KEY</translation>
    </message>
    <message>
        <source>SECRET_KEY</source>
        <translation>SECRET_KEY</translation>
    </message>
    <message>
        <source>Languages</source>
        <translation>语言</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>日语</translation>
    </message>
    <message>
        <source>Korean</source>
        <translation>韩语</translation>
    </message>
    <message>
        <source>French</source>
        <translation>法语</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation>西班牙语</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>德语</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>俄语</translation>
    </message>
    <message>
        <source>Use accurate mode</source>
        <translation>使用高精度模式</translation>
    </message>
    <message>
        <source>SEC_KEY</source>
        <translation>SEC_KEY</translation>
    </message>
    <message>
        <source>API_SEC</source>
        <translation>API_SEC</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Open in editor</source>
        <translation>手动编辑</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>FastOCR Setting</source>
        <translation>FastOCR 设置</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
</context>
</TS>

==> fastocr-0.3.7.tar.gz: fastocr-0.3.7/fastocr/i18n/zh_cn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ActionWizard</name>
    <message>
        <source>Back</source>
        <translation>上一步</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>完成</translation>
    </message>
</context>
<context>
    <name>AppTray</name>
    <message>
        <source>Capture</source>
        <translation>捕获</translation>
    </message>
    <message>
        <source>Capture (Other Languages)</source>
        <translation>捕获（其他语言）</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <source>Default backend</source>
        <translation>默认后端</translation>
    </message>
    <message>
        <source>BaiduOCR</source>
        <translation>百度文字识别服务</translation>
    </message>
    <message>
        <source>YoudaoOCR</source>
        <translation>有道 OCR 识别服务</translation>
    </message>
    <message>
        <source>Face++OCR</source>
        <translation>Face++ OCR 识别服务</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>图标主题</translation>
    </message>
    <message>
        <source>Auto Select</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>亮色</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>暗色</translation>
    </message>
    <message>
        <source>Working mode</source>
        <translation>工作模式</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>复制到系统剪贴板</translation>
    </message>
    <message>
        <source>Show notification only</source>
        <translation>仅显示通知</translation>
    </message>
    <message>
        <source>APP_ID</source>
        <translation>APP_ID</translation>
    </message>
    <message>
        <source>API_KEY</source>
        <translation>API_KEY</translation>
    </message>
    <message>
        <source>SECRET_KEY</source>
        <translation>SECRET_KEY</translation>
    </message>
    <message>
        <source>Languages</source>
        <translation>语言</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>日语</translation>
    </message>
    <message>
        <source>Korean</source>
        <translation>韩语</translation>
    </message>
    <message>
        <source>French</source>
        <translation>法语</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation>西班牙语</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>德语</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>俄语</translation>
    </message>
    <message>
        <source>Use accurate mode</source>
        <translation>使用高精度模式</translation>
    </message>
    <message>
        <source>SEC_KEY</source>
        <translation>SEC_KEY</translation>
    </message>
    <message>
        <source>API_SEC</source>
        <translation>API_SEC</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Open in editor</source>
        <translation>手动编辑</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>FastOCR Setting</source>
        <translation>FastOCR 设置</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>动作</translation>
    </message>
</context>
</TS>
